@@ -82,7 +82,7 @@ GST_DEBUG_CATEGORY_STATIC (data_protocol_debug);
 
 /* helper macros */
 
-/* write first 6 bytes of header, as well as ABI padding */
+/* write first 6 bytes of header */
 #define GST_DP_INIT_HEADER(h, version, flags, type)		\
 G_STMT_START {							\
   gint maj = 0, min = 0;					\
@@ -95,9 +95,6 @@ G_STMT_START {							\
   h[2] = (guint8) flags;					\
   h[3] = 0; /* padding byte */					\
   GST_WRITE_UINT16_BE (h + 4, type);				\
-								\
-  GST_WRITE_UINT64_BE (h + 42, (guint64) 0); /* ABI padding */	\
-  GST_WRITE_UINT64_BE (h + 50, (guint64) 0); /* ABI padding */	\
 } G_STMT_END
 
 #define GST_DP_SET_CRC(h, flags, payload, length);		\
@@ -327,7 +324,7 @@ gst_dp_init (void)
 
   _gst_dp_initialized = TRUE;
 
-  gst_dp_version_get_type ();
+  g_type_class_ref (gst_dp_version_get_type ());
 
   GST_DEBUG_CATEGORY_INIT (data_protocol_debug, "gdp", 0,
       "GStreamer Data Protocol");
@@ -370,7 +367,7 @@ gst_dp_header_payload_type (const guint8 * header)
 /**
  * gst_dp_header_from_buffer:
  * @buffer: a #GstBuffer to create a header for
- * @flags: the #GDPHeaderFlags to create the header with
+ * @flags: the #GstDPHeaderFlag to create the header with
  * @length: a guint pointer to store the header length in
  * @header: a guint8 * pointer to store a newly allocated header byte array in
  *
@@ -401,7 +398,7 @@ gst_dp_header_from_buffer_1_0 (const GstBuffer * buffer, GstDPHeaderFlag flags,
 /**
  * gst_dp_packet_from_caps:
  * @caps: a #GstCaps to create a packet for
- * @flags: the #GDPHeaderFlags to create the header with
+ * @flags: the #GstDPHeaderFlag to create the header with
  * @length: a guint pointer to store the header length in
  * @header: a guint8 pointer to store a newly allocated header byte array in
  * @payload: a guint8 pointer to store a newly allocated payload byte array in
@@ -433,7 +430,7 @@ gst_dp_packet_from_caps_1_0 (const GstCaps * caps, GstDPHeaderFlag flags,
 /**
  * gst_dp_packet_from_event:
  * @event: a #GstEvent to create a packet for
- * @flags: the #GDPHeaderFlags to create the header with
+ * @flags: the #GstDPHeaderFlag to create the header with
  * @length: a guint pointer to store the header length in
  * @header: a guint8 pointer to store a newly allocated header byte array in
  * @payload: a guint8 pointer to store a newly allocated payload byte array in
@@ -558,7 +555,7 @@ gst_dp_packet_from_event_1_0 (const GstEvent * event, GstDPHeaderFlag flags,
   /* timestamp */
   GST_WRITE_UINT64_BE (h + 10, GST_EVENT_TIMESTAMP (event));
 
-  GST_DP_SET_CRC (h, flags, *payload, pl_length);
+  GST_DP_SET_CRC (h, flags, string, pl_length);
 
   GST_LOG ("created header from event:");
   gst_dp_dump_byte_array (h, GST_DP_HEADER_LENGTH);
@@ -654,7 +651,7 @@ gst_dp_event_from_packet_0_2 (guint header_length, const guint8 * header,
   switch (type) {
     case GST_EVENT_UNKNOWN:
       GST_WARNING ("Unknown event, ignoring");
-      return FALSE;
+      return NULL;
     case GST_EVENT_EOS:
     case GST_EVENT_FLUSH_START:
     case GST_EVENT_FLUSH_STOP:
@@ -690,10 +687,10 @@ gst_dp_event_from_packet_0_2 (guint header_length, const guint8 * header,
     case GST_EVENT_NAVIGATION:
     case GST_EVENT_TAG:
       GST_WARNING ("Unhandled event type %d, ignoring", type);
-      return FALSE;
+      return NULL;
     default:
       GST_WARNING ("Unknown event type %d, ignoring", type);
-      return FALSE;
+      return NULL;
   }
 
   return event;
