@@ -27,6 +27,7 @@
 
 #include <gst/gst.h>
 
+#include "gstcapsfilter.h"
 #include "gstfakesink.h"
 #include "gstfakesrc.h"
 #include "gstfdsrc.h"
@@ -35,34 +36,35 @@
 #include "gstfilesrc.h"
 #include "gstidentity.h"
 #include "gstqueue.h"
+#include "gstqueue2.h"
 #include "gsttee.h"
 #include "gsttypefindelement.h"
+#include "gstmultiqueue.h"
 
 struct _elements_entry
 {
-  gchar *name;
+  const gchar *name;
   guint rank;
     GType (*type) (void);
 };
 
 
-/* this declaration is here because there's no gstcapsfilter.h */
-extern GType gst_capsfilter_get_type (void);
-
 static struct _elements_entry _elements[] = {
   {"capsfilter", GST_RANK_NONE, gst_capsfilter_get_type},
   {"fakesrc", GST_RANK_NONE, gst_fake_src_get_type},
   {"fakesink", GST_RANK_NONE, gst_fake_sink_get_type},
-#if HAVE_SYS_SOCKET_H
+#ifdef HAVE_SYS_SOCKET_H
   {"fdsrc", GST_RANK_NONE, gst_fd_src_get_type},
   {"fdsink", GST_RANK_NONE, gst_fd_sink_get_type},
 #endif
   {"filesrc", GST_RANK_PRIMARY, gst_file_src_get_type},
   {"identity", GST_RANK_NONE, gst_identity_get_type},
   {"queue", GST_RANK_NONE, gst_queue_get_type},
-  {"filesink", GST_RANK_NONE, gst_file_sink_get_type},
+  {"queue2", GST_RANK_NONE, gst_queue2_get_type},
+  {"filesink", GST_RANK_PRIMARY, gst_file_sink_get_type},
   {"tee", GST_RANK_NONE, gst_tee_get_type},
   {"typefind", GST_RANK_NONE, gst_type_find_element_get_type},
+  {"multiqueue", GST_RANK_NONE, gst_multi_queue_get_type},
   {NULL, 0},
 };
 
