@@ -60,8 +60,9 @@
 #  include "config.h"
 #endif
 
-#include "gsttypefindelement.h"
 #include "gst/gst_private.h"
+
+#include "gsttypefindelement.h"
 #include "gst/gst-i18n-lib.h"
 #include "gst/base/gsttypefindhelper.h"
 
@@ -162,7 +163,8 @@ gst_type_find_element_have_type (GstTypeFindElement * typefind,
 {
   g_assert (caps != NULL);
 
-  GST_INFO_OBJECT (typefind, "found caps %" GST_PTR_FORMAT, caps);
+  GST_INFO_OBJECT (typefind, "found caps %" GST_PTR_FORMAT ", probability=%u",
+      caps, probability);
   if (typefind->caps)
     gst_caps_unref (typefind->caps);
   typefind->caps = gst_caps_copy (caps);
@@ -191,13 +193,9 @@ gst_type_find_element_class_init (GstTypeFindElementClass * typefind_class)
   GObjectClass *gobject_class = G_OBJECT_CLASS (typefind_class);
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (typefind_class);
 
-  gobject_class->set_property =
-      GST_DEBUG_FUNCPTR (gst_type_find_element_set_property);
-  gobject_class->get_property =
-      GST_DEBUG_FUNCPTR (gst_type_find_element_get_property);
-  gobject_class->dispose = GST_DEBUG_FUNCPTR (gst_type_find_element_dispose);
-
-  typefind_class->have_type = gst_type_find_element_have_type;
+  gobject_class->set_property = gst_type_find_element_set_property;
+  gobject_class->get_property = gst_type_find_element_get_property;
+  gobject_class->dispose = gst_type_find_element_dispose;
 
   g_object_class_install_property (gobject_class, PROP_CAPS,
       g_param_spec_boxed ("caps", _("caps"),
@@ -232,9 +230,13 @@ gst_type_find_element_class_init (GstTypeFindElementClass * typefind_class)
       gst_marshal_VOID__UINT_BOXED, G_TYPE_NONE, 2,
       G_TYPE_UINT, GST_TYPE_CAPS | G_SIGNAL_TYPE_STATIC_SCOPE);
 
+  typefind_class->have_type =
+      GST_DEBUG_FUNCPTR (gst_type_find_element_have_type);
+
   gstelement_class->change_state =
       GST_DEBUG_FUNCPTR (gst_type_find_element_change_state);
 }
+
 static void
 gst_type_find_element_init (GstTypeFindElement * typefind,
     GstTypeFindElementClass * g_class)
@@ -278,6 +280,7 @@ gst_type_find_element_init (GstTypeFindElement * typefind,
 
   typefind->store = NULL;
 }
+
 static void
 gst_type_find_element_dispose (GObject * object)
 {
@@ -287,6 +290,10 @@ gst_type_find_element_dispose (GObject * object)
     gst_buffer_unref (typefind->store);
     typefind->store = NULL;
   }
+  if (typefind->force_caps) {
+    gst_caps_unref (typefind->force_caps);
+    typefind->force_caps = NULL;
+  }
 
   G_OBJECT_CLASS (parent_class)->dispose (object);
 }
@@ -318,6 +325,7 @@ gst_type_find_element_set_property (GObject * object, guint prop_id,
       break;
   }
 }
+
 static void
 gst_type_find_element_get_property (GObject * object, guint prop_id,
     GValue * value, GParamSpec * pspec)
@@ -606,6 +614,88 @@ gst_type_find_element_setcaps (GstPad * pad, GstCaps * caps)
   return TRUE;
 }
 
+static gchar *
+gst_type_find_get_extension (GstTypeFindElement * typefind, GstPad * pad)
+{
+  GstQuery *query;
+  gchar *uri, *result;
+  size_t len;
+  gint find;
+
+  query = gst_query_new_uri ();
+
+  /* try getting the caps with an uri query and from the extension */
+  if (!gst_pad_peer_query (pad, query))
+    goto peer_query_failed;
+
+  gst_query_parse_uri (query, &uri);
+  if (uri == NULL)
+    goto no_uri;
+
+  GST_DEBUG_OBJECT (typefind, "finding extension of %s", uri);
+
+  /* find the extension on the uri, this is everything after a '.' */
+  len = strlen (uri);
+  find = len - 1;
+
+  while (find >= 0) {
+    if (uri[find] == '.')
+      break;
+    find--;
+  }
+  if (find < 0)
+    goto no_extension;
+
+  result = g_strdup (&uri[find + 1]);
+
+  GST_DEBUG_OBJECT (typefind, "found extension %s", result);
+  gst_query_unref (query);
+  g_free (uri);
+
+  return result;
+
+  /* ERRORS */
+peer_query_failed:
+  {
+    GST_WARNING_OBJECT (typefind, "failed to query peer uri");
+    gst_query_unref (query);
+    return NULL;
+  }
+no_uri:
+  {
+    GST_WARNING_OBJECT (typefind, "could not parse the peer uri");
+    gst_query_unref (query);
+    return NULL;
+  }
+no_extension:
+  {
+    GST_WARNING_OBJECT (typefind, "could not find uri extension in %s", uri);
+    gst_query_unref (query);
+    g_free (uri);
+    return NULL;
+  }
+}
+
+static GstCaps *
+gst_type_find_guess_by_extension (GstTypeFindElement * typefind, GstPad * pad,
+    GstTypeFindProbability * probability)
+{
+  gchar *ext;
+  GstCaps *caps;
+
+  ext = gst_type_find_get_extension (typefind, pad);
+  if (!ext)
+    return NULL;
+
+  caps = gst_type_find_helper_for_extension (GST_OBJECT_CAST (typefind), ext);
+  if (caps)
+    *probability = GST_TYPE_FIND_MAXIMUM;
+
+  g_free (ext);
+
+  return caps;
+}
+
 static GstFlowReturn
 gst_type_find_element_chain (GstPad * pad, GstBuffer * buffer)
 {
@@ -752,9 +842,11 @@ gst_type_find_element_activate (GstPad * pad)
      2. try to pull type find.
      3. deactivate pull mode.
      4. src pad might have been activated push by the state change. deactivate.
-     5. if we didn't find any caps, fail.
-     6. emit have-type; maybe the app connected the source pad to something.
-     7. if the sink pad is activated, we are in pull mode. succeed.
+     5. if we didn't find any caps, try getting the uri extension by doing an uri
+     query.
+     6. if we didn't find any caps, fail.
+     7. emit have-type; maybe the app connected the source pad to something.
+     8. if the sink pad is activated, we are in pull mode. succeed.
      otherwise activate both pads in push mode and succeed.
    */
 
@@ -772,6 +864,7 @@ gst_type_find_element_activate (GstPad * pad)
     if (peer) {
       gint64 size;
       GstFormat format = GST_FORMAT_BYTES;
+      gchar *ext;
 
       if (!gst_pad_query_duration (peer, &format, &size)) {
         GST_WARNING_OBJECT (typefind, "Could not query upstream length!");
@@ -787,10 +880,12 @@ gst_type_find_element_activate (GstPad * pad)
         gst_object_unref (peer);
         return FALSE;
       }
+      ext = gst_type_find_get_extension (typefind, pad);
 
-      found_caps = gst_type_find_helper_get_range (GST_OBJECT_CAST (peer),
+      found_caps = gst_type_find_helper_get_range_ext (GST_OBJECT_CAST (peer),
           (GstTypeFindHelperGetRangeFunction) (GST_PAD_GETRANGEFUNC (peer)),
-          (guint64) size, &probability);
+          (guint64) size, ext, &probability);
+      g_free (ext);
 
       gst_object_unref (peer);
     }
@@ -803,6 +898,11 @@ gst_type_find_element_activate (GstPad * pad)
   gst_pad_activate_push (typefind->src, FALSE);
 
   /* 5 */
+  if (!found_caps || probability < typefind->min_probability) {
+    found_caps = gst_type_find_guess_by_extension (typefind, pad, &probability);
+  }
+
+  /* 6 */
   if (!found_caps || probability < typefind->min_probability) {
     GST_ELEMENT_ERROR (typefind, STREAM, TYPE_NOT_FOUND, (NULL), (NULL));
     gst_caps_replace (&found_caps, NULL);
@@ -810,13 +910,13 @@ gst_type_find_element_activate (GstPad * pad)
   }
 
 done:
-  /* 6 */
+  /* 7 */
   g_signal_emit (typefind, gst_type_find_element_signals[HAVE_TYPE],
       0, probability, found_caps);
   gst_caps_unref (found_caps);
   typefind->mode = MODE_NORMAL;
 
-  /* 7 */
+  /* 8 */
   if (gst_pad_is_active (pad))
     return TRUE;
   else {
