@@ -399,6 +399,87 @@ GST_START_TEST (test_push_linked)
 
 GST_END_TEST;
 
+static GstBuffer *
+buffer_from_string (gchar * str)
+{
+  guint size;
+  GstBuffer *buf;
+
+  size = strlen (str);
+  buf = gst_buffer_new_and_alloc (size);
+  memcpy (GST_BUFFER_DATA (buf), str, size);
+  GST_BUFFER_SIZE (buf) = size;
+
+  return buf;
+}
+
+GST_START_TEST (test_push_buffer_list_compat)
+{
+  GstPad *src, *sink;
+  GstPadLinkReturn plr;
+  GstCaps *caps;
+  GstBufferList *list;
+  GstBufferListIterator *it;
+  GstBuffer *buffer;
+
+  /* setup */
+  sink = gst_pad_new ("sink", GST_PAD_SINK);
+  fail_if (sink == NULL);
+  gst_pad_set_chain_function (sink, gst_check_chain_func);
+  /* leave chainlistfunc unset */
+
+  src = gst_pad_new ("src", GST_PAD_SRC);
+  fail_if (src == NULL);
+
+  caps = gst_caps_from_string ("foo/bar");
+
+  gst_pad_set_caps (src, caps);
+  gst_pad_set_caps (sink, caps);
+
+  plr = gst_pad_link (src, sink);
+  fail_unless (GST_PAD_LINK_SUCCESSFUL (plr));
+
+  list = gst_buffer_list_new ();
+
+  /* activate pads */
+  gst_pad_set_active (src, TRUE);
+  gst_pad_set_active (sink, TRUE);
+
+  /* test */
+  /* adding to a buffer list will drop the ref to the buffer */
+  it = gst_buffer_list_iterate (list);
+  gst_buffer_list_iterator_add_group (it);
+  gst_buffer_list_iterator_add (it, buffer_from_string ("List"));
+  gst_buffer_list_iterator_add (it, buffer_from_string ("Group"));
+  gst_buffer_list_iterator_add_group (it);
+  gst_buffer_list_iterator_add (it, buffer_from_string ("Another"));
+  gst_buffer_list_iterator_add (it, buffer_from_string ("List"));
+  gst_buffer_list_iterator_add (it, buffer_from_string ("Group"));
+  gst_buffer_list_iterator_free (it);
+  fail_unless (gst_pad_push_list (src, list) == GST_FLOW_OK);
+  fail_unless_equals_int (g_list_length (buffers), 2);
+  buffer = GST_BUFFER (buffers->data);
+  ASSERT_MINI_OBJECT_REFCOUNT (buffer, "buffer", 1);
+  fail_unless (memcmp (GST_BUFFER_DATA (buffer), "ListGroup", 9) == 0);
+  gst_buffer_unref (buffer);
+  buffers = g_list_delete_link (buffers, buffers);
+  buffer = GST_BUFFER (buffers->data);
+  ASSERT_MINI_OBJECT_REFCOUNT (buffer, "buffer", 1);
+  fail_unless (memcmp (GST_BUFFER_DATA (buffer), "AnotherListGroup", 16) == 0);
+  gst_buffer_unref (buffer);
+  buffers = g_list_delete_link (buffers, buffers);
+  fail_unless (buffers == NULL);
+
+  /* teardown */
+  gst_pad_unlink (src, sink);
+  gst_object_unref (src);
+  gst_object_unref (sink);
+  ASSERT_CAPS_REFCOUNT (caps, "caps", 1);
+  gst_caps_unref (caps);
+}
+
+GST_END_TEST;
+
 GST_START_TEST (test_flowreturn)
 {
   GstFlowReturn ret;
@@ -499,8 +580,8 @@ GST_START_TEST (test_push_negotiation)
 
   /* Should fail if src pad caps are incompatible with sink pad caps */
   gst_pad_set_caps (src, caps);
-  gst_buffer_ref (buffer);
   gst_buffer_set_caps (buffer, caps);
+  gst_buffer_ref (buffer);
   fail_unless (gst_pad_push (src, buffer) == GST_FLOW_NOT_NEGOTIATED);
   ASSERT_MINI_OBJECT_REFCOUNT (buffer, "buffer", 1);
   gst_buffer_unref (buffer);
@@ -721,6 +802,7 @@ block_async_full_destroy (gpointer user_data)
 
   fail_unless (*state < 2);
 
+  GST_DEBUG ("setting state to 2");
   *state = 2;
 }
 
@@ -730,6 +812,7 @@ block_async_full_cb (GstPad * pad, gboolean blocked, gpointer user_data)
   *(gint *) user_data = (gint) blocked;
 
   gst_pad_push_event (pad, gst_event_new_flush_start ());
+  GST_DEBUG ("setting state to 1");
 }
 
 GST_START_TEST (test_block_async_full_destroy)
@@ -752,14 +835,25 @@ GST_START_TEST (test_block_async_full_destroy)
   fail_unless (state == 1);
   gst_pad_push_event (pad, gst_event_new_flush_stop ());
 
-  /* call with the same user_data, should not call the destroy_notify function
-   */
+  /* pad was already blocked so nothing happens */
   gst_pad_set_blocked_async_full (pad, TRUE, block_async_full_cb,
       &state, block_async_full_destroy);
   fail_unless (state == 1);
 
+  /* unblock with the same data, callback is called */
+  gst_pad_set_blocked_async_full (pad, FALSE, block_async_full_cb,
+      &state, block_async_full_destroy);
+  fail_unless (state == 2);
+
+  /* block with the same data, callback is called */
+  state = 1;
+  gst_pad_set_blocked_async_full (pad, TRUE, block_async_full_cb,
+      &state, block_async_full_destroy);
+  fail_unless (state == 2);
+
   /* now change user_data (to NULL in this case) so destroy_notify should be
    * called */
+  state = 1;
   gst_pad_set_blocked_async_full (pad, FALSE, block_async_full_cb,
       NULL, block_async_full_destroy);
   fail_unless (state == 2);
@@ -904,6 +998,7 @@ gst_pad_suite (void)
   tcase_add_test (tc_chain, test_name_is_valid);
   tcase_add_test (tc_chain, test_push_unlinked);
   tcase_add_test (tc_chain, test_push_linked);
+  tcase_add_test (tc_chain, test_push_buffer_list_compat);
   tcase_add_test (tc_chain, test_flowreturn);
   tcase_add_test (tc_chain, test_push_negotiation);
   tcase_add_test (tc_chain, test_src_unref_unlink);
